/*!
 * jquery.storage.js 0.0.3 - https://github.com/yckart/jquery.storage.js
 * The client-side storage for every browser, on any device.
 *
 * Copyright (c) 2012 Yannick Albert (http://yckart.com)
 * Licensed under the MIT license (http://www.opensource.org/licenses/mit-license.php).
 * 2013/02/10
 **/
;(function($, window, document) {
    'use strict';

    $.map(['localStorage', 'sessionStorage'], function( method ) {
        var defaults = {
            cookiePrefix : 'fallback:' + method + ':',
            cookieOptions : {
                path : '/',
                domain : document.domain,
                expires : ('localStorage' === method) ? { expires: 365 } : undefined
            }
        };

        try {
            $.support[method] = method in window && window[method] !== null;
        } catch (e) {
            $.support[method] = false;
        }

        $[method] = function(key, value) {
            var options = $.extend({}, defaults, $[method].options);

            this.getItem = function( key ) {
                var returns = function(key){
                    return JSON.parse($.support[method] ? window[method].getItem(key) : $.cookie(options.cookiePrefix + key));
                };
                if(typeof key === 'string') return returns(key);

                var arr = [],
                    i = key.length;
                while(i--) arr[i] = returns(key[i]);
                return arr;
            };

            this.setItem = function( key, value ) {
                value = JSON.stringify(value);
                return $.support[method] ? window[method].setItem(key, value) : $.cookie(options.cookiePrefix + key, value, options.cookieOptions);
            };

            this.removeItem = function( key ) {
                return $.support[method] ? window[method].removeItem(key) : $.cookie(options.cookiePrefix + key, null, $.extend(options.cookieOptions, {
                    expires: -1
                }));
            };

            this.clear = function() {
                if($.support[method]) {
                    return window[method].clear();
                } else {
                    var reg = new RegExp('^' + options.cookiePrefix, ''),
                        opts = $.extend(options.cookieOptions, {
                            expires: -1
                        });

                    if(document.cookie && document.cookie !== ''){
                        $.map(document.cookie.split(';'), function( cookie ){
                            if(reg.test(cookie = $.trim(cookie))) {
                                 $.cookie( cookie.substr(0,cookie.indexOf('=')), null, opts);
                            }
                        });
                    }
                }
            };

            if (typeof key !== "undefined") {
                return typeof value !== "undefined" ? ( value === null ? this.removeItem(key) : this.setItem(key, value) ) : this.getItem(key);
            }

            return this;
        };

        $[method].options = defaults;
    });
}(jQuery, window, document));
(function() {

  (function($) {
    return $.fn.betaQ = function(_arg) {
      var apiUrl, appId, facebookShareUrl, twitterShareUrl, whenUserWelcomed;
      whenUserWelcomed = _arg.whenUserWelcomed, facebookShareUrl = _arg.facebookShareUrl, twitterShareUrl = _arg.twitterShareUrl, apiUrl = _arg.apiUrl, appId = _arg.appId;
      return this.each(function() {
        var betaQ;
        if (apiUrl === 'http://betaq.co/') {
          apiUrl = 'http://www.betaq.co/';
        }
        return betaQ = new $.fn.betaQ._BetaQ({
          apiUrl: apiUrl || 'http://www.betaq.co/',
          apiVersion: 'v1',
          appId: appId,
          whenUserWelcomed: whenUserWelcomed,
          facebookShareUrl: facebookShareUrl || 'http://www.betaq.co/',
          twitterShareUrl: twitterShareUrl || 'http://www.betaq.co',
          $el: $(this)
        });
      });
    };
  })(jQuery);

}).call(this);

(function() {

  (function($) {
    return $.fn.betaQ._markup = "\n<div class=\"betaqWaitingList\">\n    <div class=\"tile\">\n        <div class=\"signInAsSomeoneElse\" style=\"display: none\">\n            <a href=\"#\">Sign in as someone else</a>\n        </div>\n\n        <div class=\"numberInFront\">...</div>\n        <div class=\"textInFront\">people in front of you</div>\n\n        <div class=\"saveYourSpot\">\n\n            <div class=\"alert\" style=\"display:none\">\n                <button class=\"close\" type=\"button\"> &times;</button>\n                <span class=\"alert-content\"> Please enter a valid email address</span>\n            </div>\n\n            <div class=\"input-append\">\n                <input class=\"input-xlarge\" type=\"text\" placeholder=\"email address\"/>\n                <button class=\"saveYourSpotBtn btn btn-danger\" type=\"button\"> Save your spot </button>\n            </div>\n\n        </div>\n\n        <div class=\"gravatar\" style=\"display:none\"></div>\n\n        <div class=\"numberBehind\"></div>\n\n        <div class=\"share\" style=\"display:none\">\n            <div class=\"twitter\">\n                <a href=\"http://twitter.com/betaqapp\" target=\"_blank\">\n                    <i class=\"icon-twitter icon-large\"/>\n                </a>\n            </div>\n            <div class=\"facebook\">\n                <a href=\"https://facebook.com/pages/Beta-Q/526398104072611\" target=\"_blank\">\n                    <i class=\"icon-facebook icon-large\"/>\n                </a>\n            </div>\n        </div>\n\n        <div class=\"welcome\" style=\"display:none\">\n            <h2>Congratulations!</h2>\n            <h2>You're in!</h2>\n\n            <button class=\"letMeInBtn btn btn-danger\"> Let me in already! </button>\n        </div>\n\n        <a href=\"http://www.betaq.co?source=widget-link\" class=\"betaq-watermark\" title=\"BetaQ - build hype for your launch!\" target=\"_blank\"><img src='http://d3l76tgz0drjg.cloudfront.net/betaq-small-watermark.png'/></a>\n    </div>\n</div>\n";
  })(jQuery);

}).call(this);

(function() {

  (function($) {
    var BetaQ;
    return $.fn.betaQ._BetaQ = BetaQ = (function() {

      BetaQ.prototype.localStorageKey = 'betaq.userdata';

      function BetaQ(_arg) {
        var userData,
          _this = this;
        this.apiUrl = _arg.apiUrl, this.apiVersion = _arg.apiVersion, this.appId = _arg.appId, this.whenUserWelcomed = _arg.whenUserWelcomed, this.facebookShareUrl = _arg.facebookShareUrl, this.twitterShareUrl = _arg.twitterShareUrl, this.$el = _arg.$el;
        this.render();
        userData = $.localStorage(this.localStorageKey);
        if (userData) {
          $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/" + userData.token, {
            dataType: 'jsonp'
          }).done(function(serverUserData) {
            $.localStorage('betaq.userdata', {
              ahead: serverUserData.ahead,
              behind: serverUserData.behind,
              hash: serverUserData.hash,
              token: serverUserData.token
            });
            if (serverUserData.hasAccess && serverUserData.userWelcomed) {
              return _this.whenUserWelcomed();
            } else if (serverUserData.hasAccess && !serverUserData.userWelcomed) {
              return _this.showWelcome();
            } else {
              return _this.showYourSpot(serverUserData);
            }
          });
        } else {
          this.showGlobalStats();
        }
      }

      BetaQ.prototype.showGlobalStats = function() {
        var _this = this;
        return $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId, {
          dataType: 'jsonp'
        }).done(function(waitingListData) {
          var ahead;
          ahead = waitingListData.numInLineTotal - waitingListData.numLetIn;
          $('.numberInFront', _this.$el).html(ahead).show();
          $('.textInFront', _this.$el).html("" + (_this._pluralizePeople(ahead)) + " in front of you").show();
          $('.saveYourSpot', _this.$el).show();
          $('.gravatar', _this.$el).hide();
          $('.numberBehind', _this.$el).hide();
          $('.welcome', _this.$el).hide();
          $('.share', _this.$el).hide();
          return $('.signInAsSomeoneElse', _this.$el).hide();
        });
      };

      BetaQ.prototype.saveYourSpot = function(e) {
        var email, promise, regex,
          _this = this;
        if (e.keyCode && e.keyCode !== 13) {
          return;
        }
        email = $('.saveYourSpot input').val();
        regex = /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
        if (!regex.test(email)) {
          $('.alert', this.$el).show();
          return;
        }
        promise = $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/create", {
          dataType: 'jsonp',
          data: {
            email: email
          }
        });
        return promise.done(function(userData) {
          $.localStorage('betaq.userdata', {
            ahead: userData.ahead,
            behind: userData.behind,
            hash: userData.hash,
            token: userData.token
          });
          if (userData.hasAccess && userData.userWelcomed) {
            return _this.whenUserWelcomed();
          } else if (userData.hasAccess && !userData.userWelcomed) {
            return _this.showWelcome();
          } else {
            return _this.showYourSpot(userData);
          }
        });
      };

      BetaQ.prototype.showWelcome = function() {
        $('.betaqWaitingList .tile > div ').hide();
        $('.betaqWaitingList .tile > .signInAsSomeoneElse ').show();
        return $('.betaqWaitingList .tile > .welcome ').show();
      };

      BetaQ.prototype.userWelcomed = function(e) {
        var promise, userData,
          _this = this;
        userData = $.localStorage(this.localStorageKey);
        promise = $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/" + userData.token + "/welcome", {
          dataType: 'jsonp'
        });
        return promise.done(function(userData) {
          return _this.whenUserWelcomed();
        });
      };

      BetaQ.prototype.showYourSpot = function(_arg) {
        var ahead, behind, hash, token;
        ahead = _arg.ahead, behind = _arg.behind, hash = _arg.hash, token = _arg.token;
        $('.numberInFront', this.$el).html(ahead);
        $('.saveYourSpot', this.$el).hide();
        $('.gravatar', this.$el).html("<img src='http://gravatar.com/avatar/" + hash + "?d=mm'/>").show();
        $('.numberBehind', this.$el).html("" + behind + " behind you").show();
        $('.share .facebook > a').attr('href', "https://www.facebook.com/share.php?u=" + (encodeURIComponent(this.facebookShareUrl)));
        $('.share .twitter > a').attr('href', "https://www.twitter.com/intent/tweet?url=" + (encodeURIComponent(this.twitterShareUrl)));
        $('.share', this.$el).show();
        return $('.signInAsSomeoneElse', this.$el).show();
      };

      BetaQ.prototype.forgetUser = function() {
        $.localStorage('betaq.userdata', null);
        return this.showGlobalStats();
      };

      BetaQ.prototype.render = function() {
        var html,
          _this = this;
        html = $.fn.betaQ._markup;
        this.$el.html(html);
        $('.saveYourSpot button.saveYourSpotBtn', this.$el).on('click', function(e) {
          return _this.saveYourSpot(e);
        });
        $('.saveYourSpot input', this.$el).on('keyup', function(e) {
          return _this.saveYourSpot(e);
        });
        $('.alert button.close', this.$el).on('click', function() {
          return _this._hideAlert();
        });
        $('.signInAsSomeoneElse a', this.$el).on('click', function() {
          return _this.forgetUser();
        });
        return $('.welcome button.letMeInBtn', this.$el).on('click', function(e) {
          return _this.userWelcomed(e);
        });
      };

      BetaQ.prototype._pluralizePeople = function(count) {
        if (count === 1) {
          return 'person';
        } else {
          return 'people';
        }
      };

      BetaQ.prototype._hideAlert = function() {
        return $('.alert', this.$el).hide();
      };

      return BetaQ;

    })();
  })(jQuery);

}).call(this);
