(function() {

  (function($) {
    var BetaQ;
    return $.fn.betaQ._BetaQ = BetaQ = (function() {

      BetaQ.prototype.localStorageKey = 'betaq.userdata';

      function BetaQ(_arg) {
        var userData,
          _this = this;
        this.apiUrl = _arg.apiUrl, this.apiVersion = _arg.apiVersion, this.appId = _arg.appId, this.whenUserWelcomed = _arg.whenUserWelcomed, this.facebookShareUrl = _arg.facebookShareUrl, this.twitterShareUrl = _arg.twitterShareUrl, this.$el = _arg.$el;
        this.render();
        userData = $.localStorage(this.localStorageKey);
        if (userData) {
          $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/" + userData.token, {
            dataType: 'jsonp'
          }).done(function(serverUserData) {
            $.localStorage('betaq.userdata', {
              ahead: serverUserData.ahead,
              behind: serverUserData.behind,
              hash: serverUserData.hash,
              token: serverUserData.token
            });
            if (serverUserData.hasAccess && serverUserData.userWelcomed) {
              return _this.whenUserWelcomed();
            } else if (serverUserData.hasAccess && !serverUserData.userWelcomed) {
              return _this.showWelcome();
            } else {
              return _this.showYourSpot(serverUserData);
            }
          });
        } else {
          this.showGlobalStats();
        }
      }

      BetaQ.prototype.showGlobalStats = function() {
        var _this = this;
        return $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId, {
          dataType: 'jsonp'
        }).done(function(waitingListData) {
          var ahead;
          ahead = waitingListData.numInLineTotal - waitingListData.numLetIn;
          $('.numberInFront', _this.$el).html(ahead).show();
          $('.textInFront', _this.$el).html("" + (_this._pluralizePeople(ahead)) + " in front of you").show();
          $('.saveYourSpot', _this.$el).show();
          $('.gravatar', _this.$el).hide();
          $('.numberBehind', _this.$el).hide();
          $('.welcome', _this.$el).hide();
          $('.share', _this.$el).hide();
          return $('.signInAsSomeoneElse', _this.$el).hide();
        });
      };

      BetaQ.prototype.saveYourSpot = function(e) {
        var email, promise, regex,
          _this = this;
        if (e.keyCode && e.keyCode !== 13) {
          return;
        }
        email = $('.saveYourSpot input').val();
        regex = /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
        if (!regex.test(email)) {
          $('.alert', this.$el).show();
          return;
        }
        promise = $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/create", {
          dataType: 'jsonp',
          data: {
            email: email
          }
        });
        return promise.done(function(userData) {
          $.localStorage('betaq.userdata', {
            ahead: userData.ahead,
            behind: userData.behind,
            hash: userData.hash,
            token: userData.token
          });
          if (userData.hasAccess && userData.userWelcomed) {
            return _this.whenUserWelcomed();
          } else if (userData.hasAccess && !userData.userWelcomed) {
            return _this.showWelcome();
          } else {
            return _this.showYourSpot(userData);
          }
        });
      };

      BetaQ.prototype.showWelcome = function() {
        $('.betaqWaitingList .tile > div ').hide();
        $('.betaqWaitingList .tile > .signInAsSomeoneElse ').show();
        return $('.betaqWaitingList .tile > .welcome ').show();
      };

      BetaQ.prototype.userWelcomed = function(e) {
        var promise, userData,
          _this = this;
        userData = $.localStorage(this.localStorageKey);
        promise = $.ajax("" + this.apiUrl + "api/" + this.apiVersion + "/app/" + this.appId + "/user/" + userData.token + "/welcome", {
          dataType: 'jsonp'
        });
        return promise.done(function(userData) {
          return _this.whenUserWelcomed();
        });
      };

      BetaQ.prototype.showYourSpot = function(_arg) {
        var ahead, behind, hash, token;
        ahead = _arg.ahead, behind = _arg.behind, hash = _arg.hash, token = _arg.token;
        $('.numberInFront', this.$el).html(ahead);
        $('.saveYourSpot', this.$el).hide();
        $('.gravatar', this.$el).html("<img src='http://gravatar.com/avatar/" + hash + "?d=mm'/>").show();
        $('.numberBehind', this.$el).html("" + behind + " behind you").show();
        $('.share .facebook > a').attr('href', "https://www.facebook.com/share.php?u=" + (encodeURIComponent(this.facebookShareUrl)));
        $('.share .twitter > a').attr('href', "https://www.twitter.com/intent/tweet?url=" + (encodeURIComponent(this.twitterShareUrl)));
        $('.share', this.$el).show();
        return $('.signInAsSomeoneElse', this.$el).show();
      };

      BetaQ.prototype.forgetUser = function() {
        $.localStorage('betaq.userdata', null);
        return this.showGlobalStats();
      };

      BetaQ.prototype.render = function() {
        var html,
          _this = this;
        html = $.fn.betaQ._markup;
        this.$el.html(html);
        $('.saveYourSpot button.saveYourSpotBtn', this.$el).on('click', function(e) {
          return _this.saveYourSpot(e);
        });
        $('.saveYourSpot input', this.$el).on('keyup', function(e) {
          return _this.saveYourSpot(e);
        });
        $('.alert button.close', this.$el).on('click', function() {
          return _this._hideAlert();
        });
        $('.signInAsSomeoneElse a', this.$el).on('click', function() {
          return _this.forgetUser();
        });
        return $('.welcome button.letMeInBtn', this.$el).on('click', function(e) {
          return _this.userWelcomed(e);
        });
      };

      BetaQ.prototype._pluralizePeople = function(count) {
        if (count === 1) {
          return 'person';
        } else {
          return 'people';
        }
      };

      BetaQ.prototype._hideAlert = function() {
        return $('.alert', this.$el).hide();
      };

      return BetaQ;

    })();
  })(jQuery);

}).call(this);
